@@ -17,6 +17,9 @@ from calculate.lib.datavars import DataVars
 import calculate.contrib
 from spyne import Service
 
+class RerunTrigger(Exception):
+    pass
+
 class CoreServiceInterface():
     ########
     # Fields
