@@ -143,9 +143,15 @@ Overwriting.".format(file=data[i_cfgname]))
                 continue
             elif answ == "use new":
                 try:
-                    with open(orig, 'wb') as fd:
-                        fd.write(readFile(data[i_cfgname], binary=True))
+                    if os.path.islink(orig) and os.path.islink(data[i_cfgname]):
+                        link_path = os.readlink(data[i_cfgname])
+                        os.unlink(orig)
+                        os.symlink(link_path, orig)
+                    else:
+                        with open(orig, 'wb') as fd:
+                            fd.write(readFile(data[i_cfgname], binary=True))
                     os.unlink(data[i_cfgname])
+
                     if filesApply:
                         try:
                             i = filesApply.index(data[i_cfgname])
